## [1.2.5](https://github.com/ocni-dtu/lcax/compare/v1.2.4...v1.2.5) (2023-08-23)


### Bug Fixes

* added pydantic.py to release/wheel ([1909c79](https://github.com/ocni-dtu/lcax/commit/1909c79afe1e0d3a8bc9f822dfc3ead8ddd6f708))

## [1.2.4](https://github.com/ocni-dtu/lcax/compare/v1.2.3...v1.2.4) (2023-08-23)


### Bug Fixes

* updated python publish command ([4b6412d](https://github.com/ocni-dtu/lcax/commit/4b6412d6a4c8c5ab87d20929b6173e70244968fe))

## [1.2.3](https://github.com/ocni-dtu/lcax/compare/v1.2.2...v1.2.3) (2023-08-23)


### Bug Fixes

* updated python dependencies ([1ba400c](https://github.com/ocni-dtu/lcax/commit/1ba400cd7ce653c66e1e3b4dc669bde8db42fc43))

## [1.2.2](https://github.com/ocni-dtu/lcax/compare/v1.2.1...v1.2.2) (2023-08-22)


### Bug Fixes

* updated Pydantic model generation ([bb61375](https://github.com/ocni-dtu/lcax/commit/bb61375d1cb25bc6881474d4a1487b71067e24cb))

## [1.2.1](https://github.com/ocni-dtu/lcax/compare/v1.2.0...v1.2.1) (2023-08-22)


### Bug Fixes

* corrected pydantic location ([9268be1](https://github.com/ocni-dtu/lcax/commit/9268be12a5b2289cb1d81ee3a82fa275aadd50f5))

## [1.2.0](https://github.com/ocni-dtu/lcax/compare/v1.1.1...v1.2.0) (2023-08-21)


### Features

* made enums lowercase and structs camelCase ([23a81f0](https://github.com/ocni-dtu/lcax/commit/23a81f0242ba14c67fd19c1e3db3ef196a515c11))

## [1.1.1](https://github.com/ocni-dtu/lcax/compare/v1.1.0...v1.1.1) (2023-08-17)


### Bug Fixes

* added test cases and fixed issues with Python packaging ([39680eb](https://github.com/ocni-dtu/lcax/commit/39680eb98d07fa5f218d0bbbea09648d7314645b))

## [1.1.0](https://github.com/ocni-dtu/lcax/compare/v1.0.0...v1.1.0) (2023-08-16)


### Features

* updated result object ([feafef6](https://github.com/ocni-dtu/lcax/commit/feafef6e7870b02befddf9dc8aef9f062020bb8b))
* updated result object ([8e096c0](https://github.com/ocni-dtu/lcax/commit/8e096c07af19dd0bf53520481b86a5773400f7b3))
* updated transport object ([98da16b](https://github.com/ocni-dtu/lcax/commit/98da16b31f76f35cfe7b43579d29cd4e52395511))

## 1.0.0 (2023-08-16)


### Bug Fixes

* updated epdx package ([d474eac](https://github.com/ocni-dtu/lcax/commit/d474eac39d4544c5fde2f1383ddcf86d0845d894))
